@@ -6,6 +6,7 @@
 
 import importlib
 import os
+from importlib.metadata import version
 from os.path import *
 from typing import *
 
@@ -25,22 +26,30 @@ def ReadFromFile(path: str) -> str:
 
 def GetVersion(o) -> str:
     if hasattr(o, '__version__'): return o.__version__
-    elif hasattr(o, 'version'): return o.version
-    elif hasattr(o, 'Version'): return o.Version
-    elif hasattr(o, 'VERSION'): return o.VERSION
-    else: raise AttributeError(f"can't get version from {o}")
+    if hasattr(o, 'version'): return o.version
+    if hasattr(o, 'Version'): return o.Version
+    if hasattr(o, 'VERSION'): return o.VERSION
+
+    raise AttributeError(f"can't get version from {o}")
 
 
-def GetRequirements(path: str) -> List[str]:
-    install_requires = []
+# def GetRequirements(path: str, **AlterateNames: str) -> List[str]:
+#     install_requires: List[str] = []
+#     for line in ReadLinesFromFile(path):
+#         line = line.strip('\n').strip()
+#         if line in AlterateNames: package = importlib.import_module(AlterateNames[line])
+#         else: package = importlib.import_module(line)
+#         VERSION = GetVersion(package)
+#         if VERSION.__class__.__name__ == 'module': VERSION = GetVersion(VERSION)
+#
+#         install_requires.append(f'{line}>={VERSION}')
+#     return install_requires
+def GetRequirements(path: str, *, seperator: str = '>=') -> List[str]:
+    install_requires: List[str] = []
     for line in ReadLinesFromFile(path):
-        line = line.strip('\n')
-        if line == 'pillow': package = importlib.import_module('PIL')
-        else: package = importlib.import_module(line)
-        VERSION = GetVersion(package)
-        if VERSION.__class__.__name__ == 'module': VERSION = GetVersion(VERSION)
+        line = line.strip()
+        install_requires.append(f'{line}{seperator}{version(line)}')
 
-        install_requires.append(f'{line}>={VERSION}')
     return install_requires
 
 pycache = '__pycache__'
